package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ContentMapper;
import com.ruoyi.system.domain.Content;
import com.ruoyi.system.service.IContentService;

/**
 * 内容信息Service业务层处理
 *
 * @author ruoyi
 * @date 2025-05-15
 */
@Service
public class ContentServiceImpl implements IContentService
{
    @Autowired
    private ContentMapper contentMapper;

    /**
     * 查询内容信息
     *
     * @param id 内容信息主键
     * @return 内容信息
     */
    @Override
    public Content selectContentById(Long id)
    {
        return contentMapper.selectContentById(id);
    }

    /**
     * 查询内容信息列表
     *
     * @param content 内容信息
     * @return 内容信息
     */
    @Override
    public List<Content> selectContentList(Content content)
    {
        return contentMapper.selectContentList(content);
    }

    /**
     * 新增内容信息
     *
     * @param content 内容信息
     * @return 结果
     */
    @Override
    public int insertContent(Content content)
    {
        return contentMapper.insertContent(content);
    }

    /**
     * 修改内容信息
     *
     * @param content 内容信息
     * @return 结果
     */
    @Override
    public int updateContent(Content content)
    {
        return contentMapper.updateContent(content);
    }

    /**
     * 批量删除内容信息
     *
     * @param ids 需要删除的内容信息主键
     * @return 结果
     */
    @Override
    public int deleteContentByIds(Long[] ids)
    {
        return contentMapper.deleteContentByIds(ids);
    }

    /**
     * 删除内容信息信息
     *
     * @param id 内容信息主键
     * @return 结果
     */
    @Override
    public int deleteContentById(Long id)
    {
        return contentMapper.deleteContentById(id);
    }
}
